==> kadu_1.1.orig.tar.bz2: kadu-1.1/kadu-core/plugin/activation/plugin-translations-loader.cpp <==
/*
 * %kadu copyright begin%
 * Copyright 2009 Wojciech Treter (juzefwt@gmail.com)
 * Copyright 2012 Piotr Dąbrowski (ultr@ultr.pl)
 * Copyright 2004 Adrian Smarzewski (adrian@kadu.net)
 * Copyright 2007, 2008, 2009, 2010, 2011, 2012, 2013, 2014 Rafał Malinowski (rafal.przemyslaw.malinowski@gmail.com)
 * Copyright 2012, 2014 Bartosz Brachaczek (b.brachaczek@gmail.com)
 * Copyright 2004, 2006 Marcin Ślusarz (joi@kadu.net)
 * %kadu copyright end%
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License as
 * published by the Free Software Foundation; either version 2 of
 * the License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program. If not, see <http://www.gnu.org/licenses/>.
 */

#include "plugin-translations-loader.h"

#include "configuration/configuration-file.h"
#include "misc/kadu-paths.h"
#include "misc/memory.h"

#include <QtCore/QCoreApplication>
#include <QtCore/QLatin1String>
#include <QtCore/QTranslator>

PluginTranslationsLoader::PluginTranslationsLoader(const QString &pluginName) noexcept :
		m_translator{make_unique<QTranslator>()}
{
	auto const lang = config_file.readEntry("General", "Language");

	if (m_translator->load(pluginName + '_' + lang, KaduPaths::instance()->dataPath() + QLatin1String{"plugins/translations"}))
		QCoreApplication::installTranslator(m_translator.get());
	else
		m_translator.reset();
}

PluginTranslationsLoader::~PluginTranslationsLoader() noexcept
{
	QCoreApplication::removeTranslator(m_translator.get());
}

==> kadu-2.1.tar.bz2: kadu-2.1/kadu-core/plugin/activation/plugin-translations-loader.cpp <==
/*
 * %kadu copyright begin%
 * Copyright 2009 Wojciech Treter (juzefwt@gmail.com)
 * Copyright 2012 Piotr Dąbrowski (ultr@ultr.pl)
 * Copyright 2004 Adrian Smarzewski (adrian@kadu.net)
 * Copyright 2007, 2008, 2009, 2010, 2011, 2012, 2013, 2014 Rafał Malinowski (rafal.przemyslaw.malinowski@gmail.com)
 * Copyright 2012, 2014 Bartosz Brachaczek (b.brachaczek@gmail.com)
 * Copyright 2004, 2006 Marcin Ślusarz (joi@kadu.net)
 * %kadu copyright end%
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License as
 * published by the Free Software Foundation; either version 2 of
 * the License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program. If not, see <http://www.gnu.org/licenses/>.
 */

#include "plugin-translations-loader.h"

#include "configuration/configuration.h"
#include "configuration/deprecated-configuration-api.h"
#include "core/application.h"
#include "misc/memory.h"
#include "misc/paths-provider.h"

#include <QtCore/QCoreApplication>
#include <QtCore/QLatin1String>
#include <QtCore/QTranslator>

PluginTranslationsLoader::PluginTranslationsLoader(const QString &pluginName) noexcept :
		m_translator{make_unique<QTranslator>()}
{
	auto const lang = Application::instance()->configuration()->deprecatedApi()->readEntry("General", "Language");

	if (m_translator->load(pluginName + '_' + lang, Application::instance()->pathsProvider()->dataPath() + QLatin1String{"plugins/translations"}))
		QCoreApplication::installTranslator(m_translator.get());
	else
		m_translator.reset();
}

PluginTranslationsLoader::~PluginTranslationsLoader() noexcept
{
	QCoreApplication::removeTranslator(m_translator.get());
}
